.. Defity documentation master file, created by
   sphinx-quickstart on Wed Aug 25 10:44:55 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Defity: Speedy library to detect file type
==========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api-ref



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
